@@ -10,7 +10,7 @@ class AtlantisClient:
     :param str client_secret: Secret do cliente cadastrado no Atlantis
     """
 
-    def __init__(self, atlantis_url, client_id, client_secret):
+    def __init__(self, client_id, client_secret, atlantis_url='https://accounts.spacetimeanalytics.com'):
         self.atlantis_url = atlantis_url
         self.client_id = client_id
         self.client_secret = client_secret
@@ -18,6 +18,9 @@ class AtlantisClient:
     def issue_token(self, code):
         """Realiza a troca do code pelo token
 
+        .. deprecated:: 0.0.8
+            Use a biblioteca authlib.
+
         Exemplo:
 
         .. code-block:: python
@@ -37,9 +40,7 @@ class AtlantisClient:
             data={
                 'code': code,
                 'client_id': self.client_id,
-                'client_secret': self.client_secret
-            },
-            params={
+                'client_secret': self.client_secret,
                 'grant_type': 'authorization_code'
             })
         response.raise_for_status()
@@ -48,6 +49,9 @@ class AtlantisClient:
     def get_public_key(self):
         """Obtém a chave pública do Atlantis para validação do token de acesso
 
+        .. deprecated:: 0.0.8
+            Use a biblioteca authlib.
+
         :return: Chave pública
         :rtype: str
         """
@@ -58,13 +62,16 @@ class AtlantisClient:
     def validate_token(self, id_token):
         """Valida token de acesso do usuário
 
+        .. deprecated:: 0.0.8
+            Use a biblioteca authlib.
+
         Exemplo:
 
         .. code-block:: python
 
             from stl_sdk.torpedo import AtlantisClient
 
-            client = AtlantisClient('https://accounts.spacetimeanalytics.com', 'client_id_abc123')
+            client = AtlantisClient('https://accounts.spacetimeanalytics.com', 'client_id_abc123', 'client_secret_123abc')
             token_payload = client.validate_token('tokenJwT')
 
         :param id_token: Token JWT do usuário gerado pelo Atlantis
@@ -89,7 +96,7 @@ class AtlantisClient:
         :rtype: dict
         """
         response = requests.post(
-            '{}/api/instrospect'.format(self.atlantis_url),
+            '{}/api/instrospect-token'.format(self.atlantis_url),
             data={
                 'token': access_token,
                 'token_type_hint': 'access_token',
@@ -99,6 +106,24 @@ class AtlantisClient:
         response.raise_for_status()
         return response.json()
 
+    def introspect_api_key(self, api_key):
+        """Verifica se a Api key é válida
+
+        :param api_key: Api key gerada pelo Atlantis
+        :type api_key: str
+        :return: Retorna dados da api key: ``actions``, ``description``, ``created_at``, etc..
+        :rtype: dict
+        """
+        response = requests.post(
+            '{}/api/introspect-apikey'.format(self.atlantis_url),
+            data={
+                'apikey': api_key,
+                'client_id': self.client_id,
+                'client_secret': self.client_secret
+            })
+        response.raise_for_status()
+        return response.json()
+
 
 class InvalidTokenError(RuntimeError):
     pass
